@@ -1115,9 +1115,6 @@ _expectations = {
         """,
      'openbsd3':
          """
-       test_audioop
-       test_rgbimg
-       test_imageop
        test_aepack
        test_al
        test_applesingle
