@@ -4,12 +4,21 @@
 """
 
 import dl
-from test_support import verbose,TestSkipped
+from test.test_support import verbose,TestSkipped
+
+import dircache
+
+libcName = ''
+for file in dircache.listdir('/usr/lib/'):
+        if 'libc.so' in file:
+                libcName = file
+                break
+
+if not libcName:
+	raise TestSkipped
 
 sharedlibs = [
-    ('/usr/lib/libc.so', 'getpid'),
-    ('/lib/libc.so.6', 'getpid'),
-    ('/usr/bin/cygwin1.dll', 'getpid'),
+    (libcName, 'getpid'),
     ]
 
 for s, func in sharedlibs:
